@@ -133,8 +133,8 @@ CalculateTreeDistance <- function(Func, tree1, tree2 = NULL,
     splits <- lapply(splits1, as.Splits)
     
     .PairDist <- function(i) {
-      s1 <- splits[[i[1]]]
-      s2 <- splits[[i[2]]]
+      s1 <- splits[[i[[1]]]]
+      s2 <- splits[[i[[2]]]]
       common <- intersect(TipLabels(s1), TipLabels(s2))
       Func(KeepTip(s1, common), KeepTip(s2, common),
            nTip = length(common), reportMatching = FALSE, ...)
@@ -144,7 +144,7 @@ CalculateTreeDistance <- function(Func, tree1, tree2 = NULL,
     splits <- as.Splits(splits1, tipLabels = tipLabels, asSplits = FALSE)
     
     .PairDist <- function(i) {
-      Func(splits[[i[1]]], splits[[i[2]]],
+      Func(splits[[i[[1]]]], splits[[i[[2]]]],
            nTip = nTip, reportMatching = FALSE, ...)
     }
     
@@ -287,7 +287,7 @@ CalculateTreeDistance <- function(Func, tree1, tree2 = NULL,
 }
 
 .CheckLabelsSame <- function(labelList) {
-  nTip <- unique(vapply(labelList, length, 0L))
+  nTip <- unique(lengths(labelList))
   if (length(nTip) != 1) {
     stop("All trees must contain the same number of leaves.")
   }
@@ -395,20 +395,76 @@ CompareAll <- function(x, Func, FUN.VALUE = Func(x[[1]], x[[1]], ...),
   if (length(FUN.VALUE) == 1) {
     .WrapReturn(ret)
   } else {
-    structure(lapply(seq_len(dim(ret)[1]), 
+    structure(lapply(seq_len(dim(ret)[[1]]), 
                      function(i) .WrapReturn(unlist(ret[i, ]))),
               names = rownames(ret))
   }
 }
 
-#' Normalize information against total present in both starting trees
-#' @param unnormalized Numeric value to be normalized.
-#' @param tree1,tree2 Trees from which `unnormalized` was calculated
-#' @param InfoInTree Function to calculate the information content of each tree
-#' @param infoInBoth Numeric specifying information content of both trees
-#' independently (optional)
-#' @param how Method for normalization
-#' @param \dots Additional parameters to `InfoInTree()` or `how`.
+#' Normalize tree distances
+#' 
+#' `NormalizeInfo()` is an internal function used to normalize information
+#' against a reference, such as the total information present in a pair of
+#' trees.
+#' 
+#' The unnormalized value(s) are normalized by dividing by a denominator
+#' calculated based on the `how` parameter.  Valid options include:
+#' 
+#' \describe{
+#'  \item{`FALSE`}{No normalization is performed; the unnormalized values
+#'  are returned.}
+#'  \item{`TRUE`}{Unless `infoInBoth` is specified, the information in
+#'  each tree is computed using `InfoInTree()`, and the two values combined
+#'  using `Combine()`.}
+#'  \item{A numeric value, vector or matrix}{`how` is used as the denominator;
+#'  the returned value is `unnormalized / how`.}
+#'  \item{A function}{Unless `infoInBoth` is specified, the information in
+#'  each tree is computed using `InfoInTree()`, and the two values combined
+#'  using `how`.  `NormalizeInfo(how = Func)` is thus equivalent to
+#'  `NormalizeInfo(how = TRUE, Combine = Func)`.}
+#' }
+#' 
+#' @param unnormalized Numeric value, vector or matrix to be normalized.
+#' @param tree1,tree2 Trees from which `unnormalized` was calculated.
+#' @param InfoInTree Function to calculate the information content of each tree.
+#' @param infoInBoth Optional numeric specifying information content of both
+#' trees independently. If unspecified (`NULL`), this will be calculated using
+#' the method specified by `how`.
+#' @param how Method for normalization, perhaps specified using the `normalize`
+#' argument to a tree distance function.  See details for options.
+#' @param \dots Additional parameters to `InfoInTree()` or `how()`.
+#' @returns `NormalizeInfo()` returns an object corresponding to the normalized
+#' values of `unnormalized`.
+#' @examples
+#' library("TreeTools", quietly = TRUE)
+#' pair1 <- c(BalancedTree(9), StarTree(9))
+#' pair2 <- c(BalancedTree(9), PectinateTree(9))
+#' 
+#' # We'll let the number of nodes define the total information in a tree
+#' Nnode(pair1)
+#' Nnode(pair2)
+#' 
+#' # Let's normalize a unit distance
+#' rawDist <- cbind(c(1, 1), c(1, 1))
+#' 
+#' # With `Combine = "+"`, the maximum distance is the sum of
+#' # the information in each tree
+#' denominator <- outer(Nnode(pair1), Nnode(pair2), "+")
+#' 
+#' NormalizeInfo(rawDist, pair1, pair2, InfoInTree = ape::Nnode, Combine = "+")
+#' rawDist / denominator
+#' 
+#' 
+#' # A denominator can be specified manually using `how`:
+#' NormalizeInfo(rawDist, pair1, pair2, InfoInTree = ape::Nnode, how = 16)
+#' rawDist / 16
+#' 
+#' 
+#' # `how` also allows the denominator to be computed from trees:
+#' outer(Nnode(pair1), Nnode(pair2), pmin)
+#' NormalizeInfo(rawDist, pair1, pair2, InfoInTree = ape::Nnode, how = pmin)
+#' rawDist / outer(Nnode(pair1), Nnode(pair2), pmin)
+#' 
 #' @keywords internal
 #' @template MRS
 #' @importFrom TreeTools KeepTip TipLabels
@@ -474,7 +530,7 @@ NormalizeInfo <- function(unnormalized, tree1, tree2, InfoInTree,
     # We require a triangular matrix suitable for a dist object
     if (.MultipleTrees(tree1)) {
       pairs <- combn(seq_along(tree1), 2)
-      nPairs <- dim(pairs)[2]
+      nPairs <- dim(pairs)[[2]]
       ret <- list(vector("list", nPairs), vector("list", nPairs))
       
       for (n in seq_len(nPairs)) {
